
body.template-theming-resources,
body.template-theming-variables {
  ul.formTabs {
    margin-top: 1.4em;
    margin-bottom: 1em;
  }
}

body.template-theming-resources {
  table.theming-resources {
    margin-top: 1.4em;

    tbody tr.not-available td {
      &.col-available, &.col-profile, &.col-for, &.col-layer {
        color: red;
      }
    }

    tbody tr.available td.col-available {
      color: #33AA33;
    }
  }
}

body.template-theming-variables {
  table.theming-variables {
    margin-top: 1.4em;

    tr.part-title td {
      font-size: $font-size-h4;
      font-weight: bold;
      padding-top: 1.4em;
      text-align: center;
    }

    td.name {
      white-space: nowrap;
    }

    td.color {
      border-left: 1px solid #ddd;
    }
  }
}

body.template-theming-icons {
  .types-with-mimetype-icons-hint {
    @extend .fa-icon;
    @extend .fa-star;
    &:before {
      color: #A00;
      font-size: 70%;
      vertical-align: top;
    }
  }

  .theming-mime-type-icons td {
    text-align: center;
    &:last-child {
      text-align: left;
    }
  }
}
